from django.conf import settings
from django.db import models
from django.template.loader import render_to_string
from django.utils.translation import ugettext_lazy as _


LANGUAGES = settings.LANGUAGES


class MailchimpFormContent(models.Model):

    class Meta:
        abstract = True
        verbose_name = "Mailchimp Form"
        verbose_name_plural = "Mailchimp Forms"

    post_url = models.CharField(
        max_length=2100,
        null=True)

    user_id = models.CharField(
        max_length=32,
        null=True)

    list_id = models.CharField(
        max_length=32,
        null=True)

    placeholder = models.CharField(
        max_length=50,
        blank=True, null=True)

    description = models.TextField(
        blank=True, null=True)

    lang = models.CharField(
        verbose_name=_("Language"),
        max_length=3,
        default=LANGUAGES[0][0],
        choices=LANGUAGES)

    def process(self, request, **kwargs):
        if request.method == 'GET':
            self.email = request.GET.get('email')

        email = getattr(self, 'email', '')
        template_vars = {
            'post_url': self.post_url,
            'user_id': self.user_id,
            'list_id': self.list_id,
            'description': self.description,
            'placeholder': self.placeholder,
            'lang': self.lang,
            'form_id': id(self),
            'email': email,
        }

        self.rendered_output = render_to_string(
            'feincms_mailchimp/signup.html',
            template_vars
        )

    def render(self, **kwargs):
        return getattr(self, 'rendered_output', '')



# -*- coding: utf-8 -*-
from django.conf.urls import url
from django.views.generic import TemplateView

from . import views

urlpatterns = [
    url(
        regex="^MailchimpFormContent/~create/$",
        view=views.MailchimpFormContentCreateView.as_view(),
        name='MailchimpFormContent_create',
    ),
    url(
        regex="^MailchimpFormContent/(?P<pk>\d+)/~delete/$",
        view=views.MailchimpFormContentDeleteView.as_view(),
        name='MailchimpFormContent_delete',
    ),
    url(
        regex="^MailchimpFormContent/(?P<pk>\d+)/$",
        view=views.MailchimpFormContentDetailView.as_view(),
        name='MailchimpFormContent_detail',
    ),
    url(
        regex="^MailchimpFormContent/(?P<pk>\d+)/~update/$",
        view=views.MailchimpFormContentUpdateView.as_view(),
        name='MailchimpFormContent_update',
    ),
    url(
        regex="^MailchimpFormContent/$",
        view=views.MailchimpFormContentListView.as_view(),
        name='MailchimpFormContent_list',
    ),
	]



# -*- coding: utf-8 -*-
from django.views.generic import (
    CreateView,
    DeleteView,
    DetailView,
    UpdateView,
    ListView
)

from .models import (
	MailchimpFormContent,
)


class MailchimpFormContentCreateView(CreateView):

    model = MailchimpFormContent


class MailchimpFormContentDeleteView(DeleteView):

    model = MailchimpFormContent


class MailchimpFormContentDetailView(DetailView):

    model = MailchimpFormContent


class MailchimpFormContentUpdateView(UpdateView):

    model = MailchimpFormContent


class MailchimpFormContentListView(ListView):

    model = MailchimpFormContent

